"use strict";

var Promise = require("bluebird");

/* exported logger */

var AbstractDbPanel = require('./AbstractDbPanel');
var Alias = require('../../map/data/Alias');
var PanelControlElementType = require('../PanelControlElementType');
var Reaction = require('../../map/data/Reaction');

var logger = require('../../logger');
var Functions = require('../../Functions');

function GenericSearchPanel(params) {
  params.panelName = "search";
  params.helpTip = "<p>search tab allows to search for particular elements or interactions in the map</p>"
      + "<p>perfect match tick box active: only terms with an exact match to the query will be returned</p>"
      + "<p>separate multiple search by semicolon</p>";
  params.placeholder = "keyword";

  AbstractDbPanel.call(this, params);

  this.createSearchGui();
}

GenericSearchPanel.prototype = Object.create(AbstractDbPanel.prototype);
GenericSearchPanel.prototype.constructor = GenericSearchPanel;

GenericSearchPanel.prototype.createSearchGui = function() {
  var searchDiv = this.getControlElement(PanelControlElementType.SEARCH_DIV);

  var perfectMatchCheckbox = Functions.createElement({
    type : "input",
    name : "searchPerfectMatch",
    inputType : "checkbox",
  });
  searchDiv.appendChild(perfectMatchCheckbox);
  this.setControlElement(PanelControlElementType.SEARCH_PERFECT_MATCH_CHECKBOX, perfectMatchCheckbox);

  var perfectMatchLabel = Functions.createElement({
    type : "span",
    content : "PERFECT MATCH"
  });
  searchDiv.appendChild(perfectMatchLabel);
};

GenericSearchPanel.prototype.createTableElement = function(element, icon) {
  if (element instanceof Alias) {
    return this.createAliasElement(element, icon);
  } else if (element instanceof Reaction) {
    return this.createReactionElement(element);
  } else {
    throw new Error("Unknown element type: " + element.constructor.name);
  }
};

GenericSearchPanel.prototype.createPreamble = function() {
  return document.createElement("div");
};

GenericSearchPanel.prototype.createReactionElement = function(reaction) {
  var self = this;
  var guiUtils = self.getGuiUtils();
  var result = document.createElement("tr");
  var td = document.createElement("td");
  result.appendChild(td);

  var div = guiUtils.createReactionElement({
    reaction : reaction
  });

  div.appendChild(guiUtils.createSeparator());
  td.appendChild(div);
  return result;
};

GenericSearchPanel.prototype.createAliasElement = function(alias, icon) {
  var self = this;
  var guiUtils = self.getGuiUtils();

  var result = document.createElement("tr");
  var td = document.createElement("td");
  result.appendChild(td);
  var div = guiUtils.createAliasElement({
    alias : alias,
    icon : icon
  });

  div.appendChild(guiUtils.createSeparator());
  td.appendChild(div);

  return result;
};

GenericSearchPanel.prototype.searchByQuery = function() {
  var self = this;
  var query = this.getControlElement(PanelControlElementType.SEARCH_INPUT).value;
  var perfect = this.getControlElement(PanelControlElementType.SEARCH_PERFECT_MATCH_CHECKBOX).checked;
  return self.getOverlayDb().searchByQuery(query, perfect, true);
};

GenericSearchPanel.prototype.getAutocomplete = function(query) {
  return this.getMap().getSearchAutocomplete(query);
};

GenericSearchPanel.prototype.init = function() {
  var query = ServerConnector.getSessionData().getSearchQuery();
  if (query !== undefined) {
    return this.getOverlayDb().searchByEncodedQuery(query, false);
  } else {
    return Promise.resolve();
  }
};

module.exports = GenericSearchPanel;
