"use strict";

var Promise = require("bluebird");

var AbstractInfoWindow = require('./AbstractInfoWindow');

function PointInfoWindow(params) {
  // call super constructor
  AbstractInfoWindow.call(this, params);

  this.pointData = params.point;

  var point = this.pointData.getPoint();
  var latLng = this.getCustomMap().fromPointToLatLng(point);
  this.googleInfowindow = new google.maps.InfoWindow({
    content : this.content,
    position : latLng
  });
  this.googleInfowindow.open(this.getCustomMap().getGoogleMap(), this.getGoogleMarker());
  this.update();
}

PointInfoWindow.prototype = Object.create(AbstractInfoWindow.prototype);
PointInfoWindow.prototype.constructor = PointInfoWindow;

PointInfoWindow.prototype.createContentDiv = function() {
  var result = document.createElement("div");
  var title = document.createElement("h3");
  title.innerHTML = "Point: " + this.pointData.getPoint();
  result.appendChild(title);

  return Promise.resolve(result);
};

PointInfoWindow.prototype.getOverlaysData = function(general) {
  return this.getCustomMap().getTopMap().getOverlayDataForPoint(this.pointData, general);
};

/**
 * Method returning identifier of the object for which this window was created.
 */
PointInfoWindow.prototype.getElementId = function() {
  if (this.pointData !== undefined) {
    return this.pointData.getId();
  } else {
    return null;
  }
};

/**
 * Method returning type of the object for which this window was created.
 */
PointInfoWindow.prototype.getElementType = function() {
  return "POINT";
};

module.exports = PointInfoWindow;
